==> paraview_5.7.0.orig.tar.xz: paraview-5.7.0/Qt/ApplicationComponents/pqPluginToolBarBehavior.cxx <==
/*=========================================================================

   Program: ParaView
   Module:  pqPluginToolBarBehavior.cxx

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#include "pqPluginToolBarBehavior.h"

#include "pqApplicationCore.h"
#include "pqInterfaceTracker.h"
#include "pqToolBarInterface.h"

#include <QMainWindow>
#include <QToolBar>

//-----------------------------------------------------------------------------
pqPluginToolBarBehavior::pqPluginToolBarBehavior(QMainWindow* parentObject)
  : Superclass(parentObject)
{
  pqInterfaceTracker* tracker = pqApplicationCore::instance()->interfaceTracker();
  this->connect(tracker, SIGNAL(interfaceRegistered(QObject*)), SLOT(addPluginInterface(QObject*)));

  // handle any already loaded plugins.
  foreach (QObject* iface, tracker->interfaces())
  {
    this->addPluginInterface(iface);
  }
}

//-----------------------------------------------------------------------------
pqPluginToolBarBehavior::~pqPluginToolBarBehavior()
{
}

//-----------------------------------------------------------------------------
void pqPluginToolBarBehavior::addPluginInterface(QObject* iface)
{
  if (pqToolBarInterface* tbi = qobject_cast<pqToolBarInterface*>(iface))
  {
    QMainWindow* mainWindow = qobject_cast<QMainWindow*>(this->parent());
    if (!mainWindow)
    {
      qWarning("Could not find MainWindow. Cannot load actions from the plugin.");
    }
    else if (QToolBar* tb = tbi->toolBar(mainWindow))
    {
      mainWindow->addToolBar(tb);
    }
  }
}

==> paraview_5.10.0~rc1.orig.tar.xz: paraview-5.10.0~rc1/Qt/ApplicationComponents/pqPluginToolBarBehavior.cxx <==
/*=========================================================================

   Program: ParaView
   Module:  pqPluginToolBarBehavior.cxx

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#include "pqPluginToolBarBehavior.h"

#include "pqApplicationCore.h"
#include "pqInterfaceTracker.h"
#include "pqToolBarInterface.h"

#include <QMainWindow>
#include <QToolBar>

//-----------------------------------------------------------------------------
pqPluginToolBarBehavior::pqPluginToolBarBehavior(QMainWindow* parentObject)
  : Superclass(parentObject)
{
  pqInterfaceTracker* tracker = pqApplicationCore::instance()->interfaceTracker();
  this->connect(tracker, SIGNAL(interfaceRegistered(QObject*)), SLOT(addPluginInterface(QObject*)));

  // handle any already loaded plugins.
  Q_FOREACH (QObject* iface, tracker->interfaces())
  {
    this->addPluginInterface(iface);
  }
}

//-----------------------------------------------------------------------------
pqPluginToolBarBehavior::~pqPluginToolBarBehavior() = default;

//-----------------------------------------------------------------------------
void pqPluginToolBarBehavior::addPluginInterface(QObject* iface)
{
  if (pqToolBarInterface* tbi = qobject_cast<pqToolBarInterface*>(iface))
  {
    QMainWindow* mainWindow = qobject_cast<QMainWindow*>(this->parent());
    if (!mainWindow)
    {
      qWarning("Could not find MainWindow. Cannot load actions from the plugin.");
    }
    else if (QToolBar* tb = tbi->toolBar(mainWindow))
    {
      mainWindow->addToolBar(tb);
    }
  }
}
